@@ -3,12 +3,12 @@
 
 # This file is part of torrentinfo.
 #
-# Foobar is free software: you can redistribute it and/or modify
+# torrentinfo is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #
-# Foobar is distributed in the hope that it will be useful,
+# torrentinfo is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
@@ -30,7 +30,7 @@ import time
 #  see pylint ticket #2481
 from string import printable  # pylint: disable-msg=W0402
 
-VERSION = '1.8.6'
+VERSION = '1.8.7'
 
 class TextFormatter:
     """Class used to format strings before printing."""
@@ -167,7 +167,7 @@ def dump(item, config, depth, newline=True, as_utf_repr=False):
     :param newline: indicates whether to insert a newline after certain strings
     :type newline: bool
     :param as_utf_repr: indicates whether only ASCII should be printed
-    :param as_utf_repr: bool
+    :type as_utf_repr: bool
     """
     def teq(comp_type):
         """Helper that checks for type equality."""
@@ -276,6 +276,8 @@ class StringBuffer:
         :type string: str
         """
         self.string = string
+        self.string_length = len(self.string)
+        self.taken = 0
 
     def unicode_get(self, length, destructive=True, replacement='×'):
         """A get method called when bytes are encountered. Casts into unicode
@@ -293,13 +295,12 @@ class StringBuffer:
         """
         if self.is_eof():
             raise StringBuffer.BufferOverrun(1)
-        if length > len(self.string):
-            raise StringBuffer.BufferOverrun(length - len(self.string))
-
+        if length > self.string_length - self.taken:
+            raise StringBuffer.BufferOverrun(length - (self.string_length - self.taken))
         try:
-            ret_val = self.string[:length]
+            ret_val = self.string[self.taken : self.taken + length]
             if destructive:
-                self.string = self.string[length:]
+                self.taken += length
             if type(ret_val) == str:
                 return ret_val
             return ret_val.decode('utf-8')
@@ -312,7 +313,7 @@ class StringBuffer:
 
         :returns: bool -- true if this instance reached end of line
         """
-        return len(self.string) == 0
+        return self.taken >= self.string_length
 
 
     def peek(self):
